summaryrefslogtreecommitdiffstats
path: root/drivers/net/wireless/iwlegacy/iwl-legacy-rs.h
diff options
context:
space:
mode:
authorStanislaw Gruszka <sgruszka@redhat.com>2011-11-15 12:30:17 +0100
committerStanislaw Gruszka <sgruszka@redhat.com>2011-11-15 12:30:17 +0100
commit0c2c885200057c44ac5660d123e199192689ca5d (patch)
treeca4d8a59465b35247f0ea434a4ef25f260f9303b /drivers/net/wireless/iwlegacy/iwl-legacy-rs.h
parent2d09b0624a1048f6424b2c7ff60ad3a42d8036ff (diff)
iwlegacy: s/index/idx/
Signed-off-by: Stanislaw Gruszka <sgruszka@redhat.com>
Diffstat (limited to 'drivers/net/wireless/iwlegacy/iwl-legacy-rs.h')
-rw-r--r--drivers/net/wireless/iwlegacy/iwl-legacy-rs.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/drivers/net/wireless/iwlegacy/iwl-legacy-rs.h b/drivers/net/wireless/iwlegacy/iwl-legacy-rs.h
index f3ee0dd67f5..bc09a5dc6d8 100644
--- a/drivers/net/wireless/iwlegacy/iwl-legacy-rs.h
+++ b/drivers/net/wireless/iwlegacy/iwl-legacy-rs.h
@@ -49,13 +49,13 @@ struct il3945_rate_info {
u8 next_rs; /* next rate used in rs algo */
u8 prev_rs_tgg; /* previous rate used in TGG rs algo */
u8 next_rs_tgg; /* next rate used in TGG rs algo */
- u8 table_rs_index; /* index in rate scale table cmd */
+ u8 table_rs_idx; /* idx in rate scale table cmd */
u8 prev_table_rs; /* prev in rate table cmd */
};
/*
- * These serve as indexes into
+ * These serve as idxes into
* struct il_rate_info il_rates[RATE_COUNT];
*/
enum {
@@ -351,7 +351,7 @@ struct il_traffic_load {
* Pointer to this gets passed back and forth between driver and mac80211.
*/
struct il_lq_sta {
- u8 active_tbl; /* index of active table, range 0-1 */
+ u8 active_tbl; /* idx of active table, range 0-1 */
u8 enable_counter; /* indicates HT mode */
u8 stay_in_tbl; /* 1: disallow, 0: allow search for new mode */
u8 search_better_tbl; /* 1: currently trying alternate mode */